==> dagster_slack-0.4.3.tar.gz: dagster_slack-0.4.3/setup.py <==
import argparse
import sys

from setuptools import find_packages, setup

# pylint: disable=E0401, W0611
if sys.version_info[0] < 3:
    import __builtin__ as builtins
else:
    import builtins


def get_version(name):
    version = {}
    with open("dagster_slack/version.py") as fp:
        exec(fp.read(), version)  # pylint: disable=W0122

    if name == 'dagster-slack':
        return version['__version__']
    elif name == 'dagster-slack-nightly':
        return version['__nightly__']
    else:
        raise Exception('Shouldn\'t be here: bad package name {name}'.format(name=name))


parser = argparse.ArgumentParser()
parser.add_argument('--nightly', action='store_true')


def _do_setup(name='dagster-slack'):
    setup(
        name='dagster_slack',
        version=get_version(name),
        author='Elementl',
        license='Apache-2.0',
        description='A Slack client resource for posting to Slack',
        url='https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-slack',
        classifiers=[
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
        ],
        packages=find_packages(exclude=['test']),
        install_requires=['dagster'],
        tests_require=['responses==0.10.*'],
        zip_safe=False,
    )


if __name__ == '__main__':
    parsed, unparsed = parser.parse_known_args()
    sys.argv = [sys.argv[0]] + unparsed
    if parsed.nightly:
        _do_setup('dagster-slack-nightly')
    else:
        _do_setup('dagster-slack')

==> dagster_slack-0.5.2.post2.tar.gz: dagster_slack-0.5.2.post2/setup.py <==
import argparse
import sys

from setuptools import find_packages, setup


def get_version(name):
    version = {}
    with open("dagster_slack/version.py") as fp:
        exec(fp.read(), version)  # pylint: disable=W0122

    if name == 'dagster-slack':
        return version['__version__']
    elif name == 'dagster-slack-nightly':
        return version['__nightly__']
    else:
        raise Exception('Shouldn\'t be here: bad package name {name}'.format(name=name))


parser = argparse.ArgumentParser()
parser.add_argument('--nightly', action='store_true')


def _do_setup(name='dagster-slack'):
    setup(
        name='dagster_slack',
        version=get_version(name),
        author='Elementl',
        license='Apache-2.0',
        description='A Slack client resource for posting to Slack',
        url='https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-slack',
        classifiers=[
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
        ],
        packages=find_packages(exclude=['test']),
        install_requires=['dagster', 'slackclient==1.3.1'],
        tests_require=['responses==0.10.*'],
        zip_safe=False,
    )


if __name__ == '__main__':
    parsed, unparsed = parser.parse_known_args()
    sys.argv = [sys.argv[0]] + unparsed
    if parsed.nightly:
        _do_setup('dagster-slack-nightly')
    else:
        _do_setup('dagster-slack')
